"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.wScale = exports.hScale = exports.SCREEN_WIDTH = exports.SCREEN_HEIGHT = exports.BASE_WIDTH = void 0;
var _reactNative = require("react-native");
var _reactNativeResponsiveScreen = require("react-native-responsive-screen");
const BASE_WIDTH = 414;
exports.BASE_WIDTH = BASE_WIDTH;
const BASE_HEIGHT = 736;
const SCREEN_WIDTH = _reactNative.Dimensions.get('window').width;
exports.SCREEN_WIDTH = SCREEN_WIDTH;
const SCREEN_HEIGHT = _reactNative.Dimensions.get('window').height;
exports.SCREEN_HEIGHT = SCREEN_HEIGHT;
const wRatio = SCREEN_WIDTH / BASE_WIDTH;
const hRatio = SCREEN_HEIGHT / BASE_HEIGHT;

/**
 * @alias: width scale
 * @description: use to scale horizontal unit:
 * - width, marginLeft, marginRight, paddingLeft, paddingRight, ...
 * - font size
 */
const wScale = function (size) {
  let minFactor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.8;
  const minSize = size * minFactor;
  const maxSize = size * (2 - minFactor);
  const scaledSize = (0, _reactNativeResponsiveScreen.widthPercentageToDP)(100 * size / BASE_WIDTH * wRatio);
  if (scaledSize > maxSize) {
    return maxSize;
  }
  return scaledSize > minSize ? scaledSize : minSize;
};

/**
 * @alias: height scale
 * @description: use to scale vertical unit like height, marginTop, marginBottom, paddingTop, paddingBottom
 */
exports.wScale = wScale;
const hScale = function (size) {
  let minFactor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.8;
  const minSize = size * minFactor;
  const maxSize = size * (2 - minFactor);
  const scaledSize = (0, _reactNativeResponsiveScreen.heightPercentageToDP)(100 * size / BASE_HEIGHT * hRatio);
  if (scaledSize > maxSize) {
    return maxSize;
  }
  return scaledSize > minSize ? scaledSize : minSize;
};
exports.hScale = hScale;
//# sourceMappingURL=sizes.js.map